@@ -1,10 +1,13 @@
-from typing import Optional, Union
+from typing import Optional
+from typing import Union
+
 from pydantic import Field
+
 from mmisdk.common.base_model import BaseModel
+from mmisdk.common.dec_string import DecString
 from mmisdk.common.empty_string import EmptyString
 from mmisdk.common.ethereum_address import EthereumAddress
 from mmisdk.common.hex_string import HexString
-from mmisdk.common.dec_string import DecString
 
 
 class CactusTransactionDetail(BaseModel):
